% computes the steady state of fs2000 analyticaly
% largely inspired by the program of F. Schorfheide
function [ys,check] = fs2000a_steadystate(ys)
  % Inputs:
  %   ys: initial values declared in INITVAL in alphabetical order of the
  %       variables
  % Ouputs:
  %   ys: computed steady state values in alphabetical order of the
  %       variables
  %   check: steady state OK=0; problem in computing steady state = 1 
  % Structural parameters of the model are declared as global  
  global deltap betap alphap rhop;

  check = 0;
  
  zss = 0;
  kss = (1/alphap*(1/betap-1+deltap))^(1/(alphap-1));
  yss = kss^(alphap);
  css = kss^alphap-deltap*kss;
  iss = deltap*kss;
  lambdass = 1/css;
  gammass = 1/css;

  
  yv = yss;
  cv = css;
  kv = kss;
  iv = iss;
  zv = 0;
  lambdav = lambdass;
  gammav = gammass;
  
  ys =[
      cv     
gammav 
iv     
kv     
lambdav
yv     
zv   
      ];