function [loglik,d]=kfdiffuse(y,a,A,R0,R,Q0,Q,T,Z,H,tol0)
% This routine follows the notation in Durbin and Koopman
% the filter takes the form
% transition equation
% alpha_{t+1} = T_t alpha_t + R_t eta_t
% observation equation
% y_t = Z_t alpha_t + epsilon_t
% eta_t is normally distributed with mean 0 and var/cov (Q)
% epsilon is normally distributed with mean 0 and var/cov (H)
% the vector y is {y_1, y_2, y_3,...,y_n}, where the observation vectors are
% stacked horizontally.
% 
% the function returns -1 times the loglikelihood

nobs = size(y,2);
nvars = size(y,1);
nfixed = size(a,1);

loglik = 0;
wsum = 0;
d = 0;

a0 = a;
% from line below eq 5.17 embedded in text
Pinf = A*A';
Pstar = R0*Q0*R0';

for indxt=1:nobs
    if (Pinf<tol0)
        if (indxt==d+1)
           % define transition matrices
           a = a0;
           P = Pstar;
        end
        
        v = y(:,indxt)-Z*a;
        F = Z*P*Z' + H;
        Finv = inv(F);
        % K is the Kalman gain matrix: See equation 13.2.19 in Hamilton
        % the Kalman gain matrix allows one to revise the forcast
        % of alpha_{t+1} by aggregating info contained in the the forcast of
        % alpha_t at time t-1 and the info from the time t observations.
        K = T*P*Z'*Finv;
        L = T-K*Z;
        a = T*a + K*v;
        % book says 
        %P = T*P*L'+R*Q*R';
        P = L*P*L'+R*Q*R';  
        loglik = loglik + log(det(F))+v'*Finv*v;
    else
        d = d+1;
        Finf = Z * Pinf * Z';
        Fstar  = Z * Pstar * Z';
        Minf = Pinf*Z';
        Mstar = Pstar*Z';
        F1 = inv(Finf);
        F2 = -F1*Fstar*F1;
        K0 = T*Minf*F1;
        K1 = T*Mstar*F1+T*Minf*F2;
        L0 = T-K0*Z;
        L1 = -K1*Z;
        v0 = y(:,indxt) - Z*a0;
        % v1 = - Z*a1;
        
        % update matrices
        % from 5.13
        a0 = T*a0+K0*v0;
        Pstar = T*Pinf*L1' + T*Pstar*L0' + R*Q*R';
        %Pinf = T * Pinf * T';
        Pinf = T * Pinf * L0';
       
        if Finf < tol0
            w = log(det(Fstar))+v0'*inv(Fstar)*v0;
        else
            w = log(det(Finf));
        end
        % use 7.3
        loglik = loglik+w;
    end
end


loglik = loglik/2 + nobs*nvars/2*log(2*pi);

