clear
% zdata will hold the data matrix used to estimate the model parameters
global modnam parnam1 parnam2 
global paramlabels upperbound lowerbound
global lineardetrendswitch lineardetrendconst
global decrule scof endog_

% sets the path to the AIM for Matlab routines needed in solving the model
setpathaim;

% modname below chooses model
% directory. But simple param choices are made from paramfile in current
% directory.
modnam = 'rbcgrowth';

nreps = 1;                   %number of samples generated for Monte Carlo
TT = 400;                    %length of estimation samples

%model parameters
parnam1 = ['param']; %holds fundamental structural parameters
parnam2 = ['defparam'];  %holds model parameters that are functions of fundamental structural parameters

lineardetrendswitch = 0;     
lineardetrendconst = 0;


eval(parnam1); eval(parnam2);

% solve model 
% eggmodfun calls matlab AIM routine.
% eggmodfunsparse calls mex file with sparse AIM routine.
% eggmodfunsparse is only marginally faster for small models.
%[decrule,endog_]=eggmodfun(modnam,paramfilename);
[decrule,endog_,scof,eqtype_,param_]=eggmodfun(modnam,parnam1,parnam2);
 

paramlabels = char(   'rho_z','std_z');
params = [              .9      1   ];
upperbound = [          .99     10   ];
lowerbound = [          .1      0.1  ];



% check parameters
nparams = size(paramlabels,1);
for i =1:nparams
    if (upperbound(i)<lowerbound(i))
        error(['Check upperbound and lowerbound for parameter ',num2str(i)])
    end
end

% observables 
observedlabels = char('c');

paramhistory = zeros(nreps,max(size(params)));
exitflag = zeros(nreps,1);
for i=1:nreps
    seed = i;
    % Turn on for filter initialized with steady-state and training
    [paramhistory(i,:) exitflag(i)]=estimfun(observedlabels,params,TT,seed);
    
    % Turn on for filter with diffuse prior
    %[paramhistory(i,:) exitflag(i)]=estimfundiffuse(observedlabels,params,TT,seed);

end



%% print and save estimation output
nparams = size(paramlabels,1)
for i=1:nparams
    display([paramlabels(i,:),' = ',num2str(paramhistory(1,i))])
    eval([paramlabels(i,:) '=paramhistory(1,i);'])
end




