clear 
setpath

% choose parameters governing the signal extraction problem
rho = 0.9;
sigma1 = 1;
sigma2 = 1;
nobs = 100;


% form the matrices for the state space representation, following
% Hamilton's notation.
F = [rho 0
    0 0]; 

cholQ = [ sigma1 0
          0 sigma2 ];

H = [1; 1];

% generate data
randn('seed',1);
xihistory = zeros(2,nobs);
for i=2:nobs
    xihistory(:,i) = F*xihistory(:,i-1) + cholQ*randn(2,1);
end
y = H'*xihistory;    

%evaluate likelihood at true parameters
params = [rho; sigma1; sigma2];
penalty = 1e5;
upperbound = [.999; 100; 100];
lowerbound = [-.999; 0.001; 0.001];
xi10 = xihistory(:,1);
ntrain = 1;

   
% look for maximum likelihood estimates
options = optimset('HessUpdate','bfgs','display','iter',...
    'MaxIter',1000,'MaxFunEvals',20000,'TolFun',1e-5,'TolX',1e-05);

% estimates will be in thetaunc
[thetaunc,fvalunc,exitflag] = fminunc('updatematrices',params,options,...
                             y,xi10,ntrain,penalty,upperbound,lowerbound);

[thetaunc,fvalunc,exitflag] = fminsearch('updatematrices',thetaunc,options,...
                             y,xi10,ntrain,penalty,upperbound,lowerbound);

% get filtered estimates of the states, given the parameter estimates                         
[logLikel errcode xi10history] = updatematriceshistory(thetaunc,y,xi10,ntrain,penalty,upperbound,lowerbound);

% make plots and report results
figure; subplot(2,1,1); plot(1:nobs,y,'k',1:nobs,H'*xi10history,'r.-')
legend('data','filtered estimates')

subplot(2,1,2); plot(1:nobs,y-H'*xi10history)
legend('In-sample forecast error')

display(['The estimate of \rho is ',num2str(thetaunc(1))])
display(['The estimate of \sigma1 is ',num2str(thetaunc(2))])
display(['The estimate of \sigma2 is ',num2str(thetaunc(3))])
                         